告白 (豆瓣)
Description: 告白电影简介和剧情介绍,告白影评、图片、预告片、影讯、论坛、在线购票
Keywords: 告白,告白,告白影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.141豆瓣电影Top250

# 告白 (2010)

导演: 中岛哲也
编剧: 中岛哲也 / 凑佳苗
主演: 松隆子 / 冈田将生 / 木村佳乃 / 西井幸人 / 桥本爱 / 芦田爱菜 / 三吉彩花 / 藤原薰 / 井之胁海 / 清水尚弥 / 高桥努 / 一井直树 / 能年玲奈 / 新井浩文 / 野本萤
类型: 剧情 / 悬疑
官方网站: kokuhaku-shimasu.jp
制片国家/地区: 日本
语言: 日语
上映日期: 2010-06-05(日本)
片长: 106分钟
又名: 自白 / 母亲 / Kokuhaku / Confessions
IMDb: tt1590089
豆瓣评分
引用
8.8
646684人评价
5星
51.4%
4星
37.4%
3星
9.7%
2星
1.1%
1星
0.5%
好于 98% 悬疑片
好于 97% 剧情片
想看 看过
评价:
推荐

## 告白的剧情简介 · · · · · ·

一所平凡的中学，1年B组即将迎来春假。不知天高地厚的学生们肆意吵闹，殊不知一场绵亘数月的风暴正向他们袭来。级任教师森口悠子（松隆子 饰）全然无视这片混乱，静静地向学生们做出最后的告白。这个单亲妈妈独自抚养着可爱的女儿（芦田爱菜 饰），然而女儿最终在游泳池中溺水身亡。警察 认定这是一起意外，森口则认定女儿死于班上两个学生之手。她不动声色地指责着犯人A和B，并宣布用自己的方式进行复仇。在此之后，森口辞去教师职务，1年B班的学生也心怀惴惴迎来了春假。新学期开始，残酷的风暴袭向了这群无知无畏的少男少女……
本片根据湊かなえ的原作改编，并成为2010年电影旬报十佳影片；第34届日本电影学院奖最佳作品、最佳导演、最佳剧本和最佳剪辑4项大奖。 ©豆瓣

## 告白的演职员 · · · · · · ( 全部 35 )

- 中岛哲也 导演
- 松隆子 饰 森口悠子
- 冈田将生 饰 寺田良辉
- 木村佳乃 饰 下村优子
- 西井幸人 饰 渡边修哉
- 桥本爱 饰 北原美月

## 告白的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片1347 · 添加 )

## 告白的获奖情况 · · · · · · ( 全部 )

- 第30届香港电影金像奖
- 最佳亚洲电影

- 第34届日本电影学院奖
- 最佳影片

- 第5届亚洲电影大奖
- 我最喜爱的男女主角 我最喜爱的女主角(提名)
- 松隆子

## 喜欢这部电影的人也喜欢 · · · · · ·

  记忆碎片

  禁闭岛

  致命ID

  看不见的客人

  恐怖游轮

  杀人回忆

  七宗罪

  沉默的羔羊

  控方证人

  嫌疑人X的献身

我要写短评

## 告白的短评 · · · · · · ( 全部 178579 条 )

热门 / 最新 / 好友

### 6443 有用 木卫二 看过 2011-01-21 23:26:14

都是你爸害的（《松子》），都是你妈逼的（《告白》），中岛哲也太喜欢成长阴影了吧……

### 2473 有用 桃桃林林 看过 2010-11-06 20:34:15

等本片有下载的时候一定会有不少恶评，与以往的中岛哲也完全不同，大量的特写与高速慢镜的运用，全片好似分段式MV，情节上各种意识流似的拼贴。导演视乎在还原一种心理动作。谈不上非常喜欢，但却仍想赞一下。

### 2614 有用 Dulcixote 看过 2011-01-27 15:58:47

这片告诉我们，正太与萝莉都是斗不过御姐的……

### 9431 有用 shiya 看过 2010-06-30 20:04:38

当罪人无法通过法律将其制裁的时候，唯有以暴制暴。 本以为是个推理片，想不到电影一开始就已经知道犯人是谁，只剩下女教师的复仇；本以为她在关键时刻会俗套地圣母一把，看在对方“还是个孩子”的份上原谅杀死自己女儿的学生，想不到她腹黑到底，把两个少年折磨到求生不得求死不能。太tm帅了。

### 3910 有用 内陆飞鱼 看过 2011-01-22 10:01:36

中岛哲也导演《下妻物语》《被嫌弃的松子的一生》《告白》可以算华丽三部曲，都喜欢，但这部太厉害，太好看，形式感，音乐衬底，故事内容，叙事方式，以及一大堆萝莉正太扎堆，以优雅、轻松、热闹的外在形式，表达巨大的无边的哀凉和悲观，太对个人胃口了。100分。

> 更多短评 178579条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 告白的影评 · · · · · · ( 全部 3091 条 )

热门 / 最新 / 好友
愛永 2010-11-02 21:13:56

## 當你真正感到痛，才會知道「痛」是什麼

这篇影评可能有剧透

我沒有看原著小說，就先看了松隆子的電影『告白』。所以，從她的第一場告白開始，一直到每個人各自的告白，我始終處於一種高度震懾的狀態，過程中亦不自覺數次深呼吸，直至劇終，精神依舊緊繃。很難具體形容電影有多銳利？卻隱約感到它一刀切開人們內心底層對世界的困惑，將所... (展开)
8227 580 745回应 收起
影子熊揉着眼睛 2011-01-24 13:22:23

## 《告白》：善良崩坏 铅色冰心

《告白》是有良心的推理作品，杀人者荒唐，但有社会成因，复仇者冰冷，但意在警世。故事人物不多，但格局很大。段落和角度海量，但叙事效率很高。和许多强调谋杀手段奇技淫巧的故事相比，这是真正关注现实，不落俗套的好故事。从神职者到传道者，森口从未单纯的理解善意，在她... (展开)
3555 138 302回应 收起
张佳玮 2011-03-02 13:15:46

## 日本式电影审美=至清澈至残忍的反差美学+暴力与死亡的主题？

作为半个栗山千明粉，有次和人开玩笑： “现在看日本电影，一看到清澈镜头抒情音乐纯净无垢的喧闹微笑以及干净的校服，就会做好心理准备：下一秒多半会出现暴力凶杀血迹特写以及孩子们沉静微笑面部特写。” 我对日本校园片儿的观感，差不多如此。 有朋友在京都，偶尔聊起来，... (展开)
2461 225 131回应 收起
夏树 2011-01-23 04:52:02

## 最震慑我的是孩子们

这篇影评可能有剧透

阴霾——压抑——情绪化——画面重心的绝对强调——煽动性——暴行——冷酷 这部电影从色彩基调到情感基调都互相契合并和原作相得益彰。原作中单靠文字就能传递出的渗透骨髓的绝望和震撼，在中岛哲也的手下得以原汁原味的呈现。 《告白》这本书我很早就注意到了，它在日本开... (展开)
935 80 129回应 收起
望月封道 2011-01-25 11:39:36

## 永遠不會結束的告白

比起北野武的《極惡非道》，《告白》其實更配得上“全員惡人”這個頭銜。 如果說黑幫有秩序的作惡，是惡之道，小孩子的惡就更本真和純粹，可能缺少創意，但幾乎沒有理由夾雜其中，所以惡得更透澈。 上個世紀的聖人史懷哲，在他的《文化哲學》裏面提出的敬畏生命倫理學。在他... (展开)
378 35 101回应 收起
志之 2011-01-25 07:07:43

## 殉道者北原美月

这篇影评可能有剧透

女初中生北原美月，在小说中被定为“殉道者”，在电影中同样分量十足却易于被忽视。美月的作用在其出场后不久就已经由角色自己说出来了 “老师，这个班级不正常” 换言之，美月是从一个正常者的角度在察觉并观察到所有的”不正常“，这点是她与热血老师的区别，后者对正在发生... (展开)
368 33 41回应 收起
木卫二 2011-05-19 22:13:54

## 夸张的形式，自然的罪恶

如同2006年的《被嫌弃的松子的一生》，《告白》一推出就产生了火爆的话题效应。影片在日本国内票房高收，周边市场也表现不俗。然而跟获得压倒性好评的《被嫌弃的松子的一生》不同，《告白》在褒赞声音以外，批评言论同样来得相当刺耳，大有置于死地而后快的决绝。专业刊物上，... (展开)
218 32 16回应 收起
HELEN 2011-01-27 16:51:55

## 《告白》：真正残忍的是谁？

这篇影评可能有剧透

人之初，性本善。这是老祖先说的。讨论人性的善恶并不是这部电影的主题。对我来说那句“听到重要的东西消失的声音”更具有重要含义。 初中女老师四岁的女儿被自己的学生杀死。在学期结业课上她平静地向学生讲这一件事。讲台底下一片混乱。没有人觉得这是一件惊恐和悲痛的事。... (展开)
276 67 68回应 收起
深津奈留 2011-01-29 20:31:59

## 有点无奈的也来谈谈告白

因为并没有给书写评，本来电影也不打算说什么的，虽然事前我期待值很高。 电影拍得不错，当然也没有那么多装逼犯说的那么高深。作为中岛哲也的电影来看，是部佳作。 然而电影对原作最大的改变，就是几乎彻底颠覆了森口的根源。 告白这部东西啊，它原本讲的并非是中岛想要表达的... (展开)
92 21 26回应 收起

> 更多影评 3091篇

添加新讨论

## 讨论区 · · · · · ·

问问大家看完之后有没有特别压抑的感觉… | 来自芋泥牛奶三分糖 | 25 回应 | 2022-11-24 20:35:01
还有什么告白类似的电影？ | 来自子恒 | 70 回应 | 2022-11-21 20:42:47
请问怎么可以看的呀 | 来自及豆N0 | 23 回应 | 2022-11-21 04:07:18
里面的小演员演技太棒了吧，尤其是A和B | 来自达里尔的弩 |  | 2022-11-19 11:42:21
还有没有像告白这样的电影 真的太喜欢了 | 来自安安 | 12 回应 | 2022-11-14 20:40:15

> 去这部影片的讨论区（全部290条）

## 关于《告白》的问题 · · · · · · ( 全部51个 )

- 有关儿童演员的保护？ 14人回答
- 电影中的几处是通过凸面镜的画面来表现的，谁知道这种特殊的镜头语言是何用意？ 7人回答

> 全部51个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 他们是高智商玩家 (中间元素)
- 【大爱の日剧♂电影♀动画全收录】 (狷介有乌青)
- 意外结局+高智商 (鸟人与鱼)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- 有才的二哈
  刚刚 看过
- 沉默是最好的
  3分钟前 看过
- 南安笙歌
  4分钟前 想看

871167人看过 / 249557人想看

订阅告白的评论:
feed: rss 2.0